@@ -12,7 +12,7 @@
  * method hashPassword based on code from the phpLDAPadmin development team (http://phpldapadmin.sourceforge.net/).
  * method randomSalt based on code from the phpLDAPadmin development team (http://phpldapadmin.sourceforge.net/).
  *
- * Copyright (C) 2005-2014, The Roundcube Dev Team
+ * Copyright (C) The Roundcube Dev Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,10 +34,11 @@ class rcube_ldap_password
     {
         $rcmail = rcmail::get_instance();
         require_once 'Net/LDAP2.php';
+        require_once __DIR__ . '/ldap_simple.php';
 
         // Building user DN
         if ($userDN = $rcmail->config->get('password_ldap_userDN_mask')) {
-            $userDN = self::substitute_vars($userDN);
+            $userDN = rcube_ldap_simple_password::substitute_vars($userDN);
         }
         else {
             $userDN = $this->search_userdn($rcmail);
@@ -48,7 +49,7 @@ class rcube_ldap_password
         }
 
         // Connection Method
-        switch($rcmail->config->get('password_ldap_method')) {
+        switch ($rcmail->config->get('password_ldap_method')) {
             case 'admin':
                 $binddn = $rcmail->config->get('password_ldap_adminDN');
                 $bindpw = $rcmail->config->get('password_ldap_adminPW');
@@ -61,7 +62,7 @@ class rcube_ldap_password
         }
 
         // Configuration array
-        $ldapConfig = array (
+        $ldapConfig = [
             'binddn'    => $binddn,
             'bindpw'    => $bindpw,
             'basedn'    => $rcmail->config->get('password_ldap_basedn'),
@@ -69,7 +70,7 @@ class rcube_ldap_password
             'port'      => $rcmail->config->get('password_ldap_port', '389'),
             'starttls'  => $rcmail->config->get('password_ldap_starttls'),
             'version'   => $rcmail->config->get('password_ldap_version', '3'),
-        );
+        ];
 
         // Connecting using the configuration array
         $ldap = Net_LDAP2::connect($ldapConfig);
@@ -85,12 +86,12 @@ class rcube_ldap_password
         $smbpwattr    = $rcmail->config->get('password_ldap_samba_pwattr');
         $smblchattr   = $rcmail->config->get('password_ldap_samba_lchattr');
         $samba        = $rcmail->config->get('password_ldap_samba');
-        $encodage     = $rcmail->config->get('password_ldap_encodage', 'crypt');
+        $encodage     = $rcmail->config->get('password_ldap_encodage', 'md5-crypt');
 
         // Support multiple userPassword values where desired.
         // multiple encodings can be specified separated by '+' (e.g. "cram-md5+ssha")
         $encodages    = explode('+', $encodage);
-        $crypted_pass = array();
+        $crypted_pass = [];
 
         foreach ($encodages as $enc) {
             if ($cpw = password::hash_password($passwd, $enc)) {
@@ -120,25 +121,25 @@ class rcube_ldap_password
             return PASSWORD_CONNECT_ERROR;
         }
 
-        if (!$userEntry->replace(array($pwattr => $crypted_pass), $force)) {
+        if (!$userEntry->replace([$pwattr => $crypted_pass], $force)) {
             return PASSWORD_CONNECT_ERROR;
         }
 
         // Updating PasswordLastChange Attribute if desired
         if ($lchattr) {
-            $current_day = (int)(time() / 86400);
-            if (!$userEntry->replace(array($lchattr => $current_day), $force)) {
+            $current_day = (int) (time() / 86400);
+            if (!$userEntry->replace([$lchattr => $current_day], $force)) {
                 return PASSWORD_CONNECT_ERROR;
             }
         }
 
         // Update Samba password and last change fields
         if ($smbpwattr) {
-            $userEntry->replace(array($smbpwattr => $samba_pass), $force);
+            $userEntry->replace([$smbpwattr => $samba_pass], $force);
         }
         // Update Samba password last change field
         if ($smblchattr) {
-            $userEntry->replace(array($smblchattr => time()), $force);
+            $userEntry->replace([$smblchattr => time()], $force);
         }
 
         if (Net_LDAP2::isError($userEntry->update())) {
@@ -159,13 +160,13 @@ class rcube_ldap_password
         $binddn = $rcmail->config->get('password_ldap_searchDN');
         $bindpw = $rcmail->config->get('password_ldap_searchPW');
 
-        $ldapConfig = array (
+        $ldapConfig = [
             'basedn'    => $rcmail->config->get('password_ldap_basedn'),
             'host'      => $rcmail->config->get('password_ldap_host', 'localhost'),
             'port'      => $rcmail->config->get('password_ldap_port', '389'),
             'starttls'  => $rcmail->config->get('password_ldap_starttls'),
             'version'   => $rcmail->config->get('password_ldap_version', '3'),
-        );
+        ];
 
         // allow anonymous searches
         if (!empty($binddn)) {
@@ -179,45 +180,23 @@ class rcube_ldap_password
             return '';
         }
 
-        $base   = self::substitute_vars($rcmail->config->get('password_ldap_search_base'));
-        $filter = self::substitute_vars($rcmail->config->get('password_ldap_search_filter'));
-        $options = array (
+        $base   = rcube_ldap_simple_password::substitute_vars($rcmail->config->get('password_ldap_search_base'));
+        $filter = rcube_ldap_simple_password::substitute_vars($rcmail->config->get('password_ldap_search_filter'));
+        $options = [
             'scope' => 'sub',
-            'attributes' => array(),
-        );
+            'attributes' => [],
+        ];
 
         $result = $ldap->search($base, $filter, $options);
+
         if (is_a($result, 'PEAR_Error') || ($result->count() != 1)) {
             $ldap->done();
             return '';
         }
+
         $userDN = $result->current()->dn();
         $ldap->done();
 
         return $userDN;
     }
-
-    /**
-     * Substitute %login, %name, %domain, %dc in $str
-     * See plugin config for details
-     */
-    static function substitute_vars($str)
-    {
-        $str = str_replace('%login', $_SESSION['username'], $str);
-        $str = str_replace('%l', $_SESSION['username'], $str);
-
-        $parts = explode('@', $_SESSION['username']);
-
-        if (count($parts) == 2) {
-            $dc = 'dc='.strtr($parts[1], array('.' => ',dc=')); // hierarchal domain string
-
-            $str = str_replace('%name', $parts[0], $str);
-            $str = str_replace('%n', $parts[0], $str);
-            $str = str_replace('%dc', $dc, $str);
-            $str = str_replace('%domain', $parts[1], $str);
-            $str = str_replace('%d', $parts[1], $str);
-        }
-
-        return $str;
-    }
 }
